init_tracing

Function init_tracing 

pub fn init_tracing() -> bool
Install a tracing subscriber that forwards Rust tracing events to the JavaScript console.

Returns true when this call installs the subscriber. Returns false when another global tracing subscriber is already installed.