pub struct PendingIssuance { /* private fields */ }Expand description
Holder-side pending issuance state required to finalize one issuer response.
Implementations
Sourceimpl PendingIssuance
impl PendingIssuance
Sourcepub fn create_request(
issuer_authority: JsValue,
info: JsValue,
blind_msg: JsValue,
) -> Result<JsValue, JsError>
pub fn create_request( issuer_authority: JsValue, info: JsValue, blind_msg: JsValue, ) -> Result<JsValue, JsError>
Create a blinded holder issuance request and local pending issuance state.
Sourcepub fn export_state(&self) -> Result<String, JsError>
pub fn export_state(&self) -> Result<String, JsError>
Export this pending issuance state as a JSON string for application storage.
Sourcepub fn import_state(state: String) -> Result<PendingIssuance, JsError>
pub fn import_state(state: String) -> Result<PendingIssuance, JsError>
Import pending issuance state previously returned by exportState.