pub struct VerificationContext { /* private fields */ }Expand description
Verifier-side context containing trusted issuers and ingested revocations.
Implementations
Sourceimpl VerificationContext
impl VerificationContext
Sourcepub fn new() -> VerificationContext
pub fn new() -> VerificationContext
Create an empty verification context.
Verify and trust an issuer authority for future credential checks.
Sourcepub fn add_revocation(&mut self, revocation: JsValue) -> Result<(), JsError>
pub fn add_revocation(&mut self, revocation: JsValue) -> Result<(), JsError>
Verify and store a signed revocation from a trusted issuer.
Sourcepub fn verify_credential(&self, credential: JsValue) -> Result<bool, JsError>
pub fn verify_credential(&self, credential: JsValue) -> Result<bool, JsError>
Verify a finalized credential against trusted issuers and ingested revocations.
Verify a credential and holder authorization.